<?php
namespace App\Http\Controllers;

use App\File;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;

class FileController extends Controller
{

    public function __construct()
    {
        // Uncomment to require authentication
        // $this->middleware('auth');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => 'required|string|regex:/^[a-zA-Z0-9\s-\.]+$/|max:255'
        ]);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view("file.index", array("files" => File::all()->sortBy("name")));
    }

    /**
     * Show the form for creating a new resource.
     * We use the same view for create and update => provide an empty File.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view("file.edit", ["file" => new File()]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validator($request->all())->validate();

        $file = new File();
        $file->name = $request->name;
        $file->save();
        return redirect(action('FileController@index'));
    }

    /**
     * Display the specified resource.
     *
     * @param  File $file     * @return \Illuminate\Http\Response
     */
    public function show(File $file)
    {
        return view("file.show", array("file" => $file));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  File $file     * @return \Illuminate\Http\Response
     */
    public function edit(File $file)
    {
        return view("file.edit", array("file" => $file));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  File $file     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, File $file)
    {
        $this->validator($request->all())->validate();

        $file->name = $request->name;
        $file->save();
        return redirect(action('FileController@index'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        File::find($id)->delete();
        return redirect(action("FileController@index"));
    }
}
